#!/usr/bin/env python

# This script installs a .schema file in the
# local MySQL schema database

import os, sys

# Main script starts here

# Check RGMA_HOME is set

try:
    rgma_home = os.environ['RGMA_HOME']
except KeyError:
    try:
        rgma_home = os.environ['GLITE_LOCATION']
    except KeyError:
        print "ERROR: Environment variable RGMA_HOME or GLITE_LOCATION must be set"
        sys.exit(1)
 
showhelp = 0
showversion = 0
user = "schema"
password = "info"
output_file = None

version = "5.0.31"

# Check command line options

files = []
args = sys.argv[1:]
previous = ""

for arg in args:
    
    if previous == "-o":
        output_file = arg.strip()
    elif previous == "-u" or previous == "--user":
        user = arg.strip()
    elif previous == "-p" or previous == "--password":
        password = arg.strip()
    elif arg == "-h" or arg == "--help":
        showhelp = 1
    elif arg == "-v" or arg == "--version":
        showversion = 1
    elif arg != "-u" and arg != "--user" and arg != "-o" and \
         arg != "-p" and arg != "--password":
        files.append(arg.strip())

    previous = arg

# Show help

if showhelp == 1:
  print "'new-rgma-install-schema' installs a .schema file in the local RGMA Schema database"
  print "Usage: new-rgma-install-schema (options) (schema files)"
  print ""
  print "Options:"
  print "    -h, --help      Display help information"
  print "    -v, --version   Display version"
  print "    -u, --user      Database username to use (default: schema)"
  print "    -p, --password  Database password to use (default: info)"
  print "    -o <file>       Write SQL commands to file rather than directly to MySQL"
  sys.exit(0)

# Show version

if showversion == 1:
  print "new-rgma-install-schema version " + version
  sys.exit(0)

if user == "":
    print "ERROR: Database username must be specified"
    print "Try new-rgma-install-schema --help for usage information"
    sys.exit(1)

if len(files) == 0:
    print "ERROR: No schema files specified"
    print "Try new-rgma-install-schema --help for usage information"
    sys.exit(1)

# If an output file is being used, truncate the file first

if output_file != None:
    if os.path.exists(output_file):
        os.remove(output_file)

# Connect to the database or open the output file

if output_file == None:
    mysql = os.popen("mysql -u " + user + " --pass=" + password, "w")
    completion_message = "Installed"
else:
    mysql = open(output_file, "w")
    completion_message = "Generated SQL for"

for file in files:

    schematool = os.path.join(rgma_home, "share/rgma/scripts/new-rgma-schema-tool.py")
    command = schematool + " --sql " + file
    output = os.popen(command)
    lines = output.readlines()
    
    status = output.close()
    if status != None:
        print "ERROR: failed to generate SQL from schema file " + file
        sys.exit(1)

    for line in lines:
        mysql.write(line + "\n")
                
    mysql.write("\n")
    print completion_message + " schema file " + file

status = mysql.close()

if status != None:
    print "ERROR: failed to execute SQL for schema files"
    sys.exit(1)

print completion_message + " %i schema files" % len(files)
